@@ -1,6 +1,6 @@
 package Map::Tube::NYC;
 
-$Map::Tube::NYC::VERSION = '0.06';
+$Map::Tube::NYC::VERSION = '0.07';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::NYC - Interface to the New York City Subway.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -23,13 +23,40 @@ has xml => (is => 'ro', default => sub { return dist_file('Map-Tube-NYC', 'nyc-m
 
 with 'Map::Tube';
 
+=encoding utf8
+
 =head1 DESCRIPTION
 
 It currently provides functionality to find the shortest  route between  the  two
-given  nodes.It covers IND Eighth Avenue Line only now.I will be adding remaining
-routes very soon.
+given  nodes. It covers the following subway lines just yet:
 
-For more information about New York City Subway, L<click here|http://en.wikipedia.org/wiki/New_York_City_Subway_map>.
+=over 2
+
+=item * L<IND Eighth Avenue Line|Map::Tube::NYC::Line::INDEighthAvenue>
+
+=back
+
+=head1 TODO (Subway Lines)
+
+=over 2
+
+=item * IND Sixth Avenue Line
+
+=item * IND Crosstown Line
+
+=item * BMT Canarsie Line
+
+=item * BMT Nassau Street Line
+
+=item * BMT Broadway Line
+
+=item * IRT Broadway – Seventh Avenue Line
+
+=item * IRT Lexington Avenue Line
+
+=item * IRT Flushing Line
+
+=back
 
 =head1 CONSTRUCTOR
 
